==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/RouteIngressConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RouteIngressConditionBuilder extends io.fabric8.openshift.api.model.RouteIngressConditionFluentImpl<io.fabric8.openshift.api.model.RouteIngressConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RouteIngressCondition,io.fabric8.openshift.api.model.RouteIngressConditionBuilder>{
  public RouteIngressConditionBuilder() {
    this(false);
  }
  public RouteIngressConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new RouteIngressCondition(), validationEnabled);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RouteIngressCondition(), validationEnabled);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent,io.fabric8.openshift.api.model.RouteIngressCondition instance) {
    this(fluent, instance, false);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent,io.fabric8.openshift.api.model.RouteIngressCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressCondition instance) {
    this(instance,false);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RouteIngressCondition build() {
    RouteIngressCondition buildable = new RouteIngressCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteIngressConditionBuilder that = (RouteIngressConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/RouteIngressConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RouteIngressConditionBuilder extends io.fabric8.openshift.api.model.RouteIngressConditionFluentImpl<io.fabric8.openshift.api.model.RouteIngressConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RouteIngressCondition,io.fabric8.openshift.api.model.RouteIngressConditionBuilder>{
  public RouteIngressConditionBuilder() {
    this(false);
  }
  public RouteIngressConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new RouteIngressCondition(), validationEnabled);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RouteIngressCondition(), validationEnabled);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent,io.fabric8.openshift.api.model.RouteIngressCondition instance) {
    this(fluent, instance, false);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent,io.fabric8.openshift.api.model.RouteIngressCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressCondition instance) {
    this(instance,false);
  }
  public RouteIngressConditionBuilder(io.fabric8.openshift.api.model.RouteIngressCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RouteIngressConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RouteIngressCondition build() {
    RouteIngressCondition buildable = new RouteIngressCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteIngressConditionBuilder that = (RouteIngressConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
